@@ -85,7 +85,7 @@ class DockerSwarmOperator(DockerOperator):
     :type tmp_dir: str
     :param user: Default user inside the docker container.
     :type user: int or str
-    :param docker_conn_id: ID of the Airflow connection to use
+    :param docker_conn_id: The :ref:`Docker connection id <howto/connection:docker>`
     :type docker_conn_id: str
     :param tty: Allocate pseudo-TTY to the container of this service
         This needs to be set see logs of the Docker container / service.
@@ -118,7 +118,7 @@ class DockerSwarmOperator(DockerOperator):
             types.TaskTemplate(
                 container_spec=types.ContainerSpec(
                     image=self.image,
-                    command=self.get_command(),
+                    command=self.format_command(self.command),
                     env=self.environment,
                     user=self.user,
                     tty=self.tty,
@@ -126,7 +126,7 @@ class DockerSwarmOperator(DockerOperator):
                 restart_policy=types.RestartPolicy(condition='none'),
                 resources=types.Resources(mem_limit=self.mem_limit),
             ),
-            name='airflow-%s' % get_random_string(),
+            name=f'airflow-{get_random_string()}',
             labels={'name': f'airflow__{self.dag_id}__{self.task_id}'},
         )
 
@@ -144,12 +144,14 @@ class DockerSwarmOperator(DockerOperator):
                 self.log.info('Service status before exiting: %s', self._service_status())
                 break
 
-        if self.auto_remove:
+        if self.service and self._service_status() != 'complete':
+            if self.auto_remove:
+                self.cli.remove_service(self.service['ID'])
+            raise AirflowException('Service did not complete: ' + repr(self.service))
+        elif self.auto_remove:
             if not self.service:
                 raise Exception("The 'service' should be initialized before!")
             self.cli.remove_service(self.service['ID'])
-        if self._service_status() == 'failed':
-            raise AirflowException('Service failed: ' + repr(self.service))
 
     def _service_status(self) -> Optional[str]:
         if not self.cli:
@@ -158,7 +160,7 @@ class DockerSwarmOperator(DockerOperator):
 
     def _has_service_terminated(self) -> bool:
         status = self._service_status()
-        return status in ['failed', 'complete']
+        return status in ['complete', 'failed', 'shutdown', 'rejected', 'orphaned', 'remove']
 
     def _stream_logs_to_output(self) -> None:
         if not self.cli:
